eprllib.RewardFunctions.energy_and_cen15251 — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.energy_and_cen15251

## Energy and CEN 15251 reward function

The standard CEN 15251 stablish three categories of acceptability of the thermal condition as is show in table below.

Title
Category | Explanation
--- | ---
Category I (90%) Acceptability | High level of expectation and is recommended for spaces occupied by very sensitive and fragile persons with special requirements like handicapped, sick, very joung children and elderly persons.
Category II (80%) Acceptability | Normal level of expectation and should be used for new buildings and renovations.
Category III (65%) Acceptability | An acceptable, moderate level of expectation and may be used for existing buildings.
Cat. IV | Values outside the criteria for the above categories. This category should only be accepted for a limited part of the year.

See Engineering Reference of EnergyPlus documentation 19.1.6 Adaptive Comfort Model Based on European Standard EN15251-2007 for more information.

Classes

`herarchical_reward_fn`(reward_fn_config) |
`reward_fn`(reward_fn_config) |